EXPORTS
	__9CLongWaiti @ 1 NONAME ; CLongWait::CLongWait(int)
	AddCommandL__18CBaseCommandParserRC7TDesC16 @ 2 NONAME ; CBaseCommandParser::AddCommandL(TDesC16 const &)
	AddCommandParserL__18CBaseSectionParserP18CBaseCommandParser @ 3 NONAME ; CBaseSectionParser::AddCommandParserL(CBaseCommandParser *)
	AddStateL__16CBaseTestHarnessP14MBaseTestStateG14TTestDebugInfo @ 4 NONAME ; CBaseTestHarness::AddStateL(MBaseTestState *, TTestDebugInfo)
	CanParse__C18CBaseCommandParserRC7TDesC16 @ 5 NONAME ; CBaseCommandParser::CanParse(TDesC16 const &) const
	CheckNumberOfArgumentsL__18CBaseCommandParseri @ 6 NONAME ; CBaseCommandParser::CheckNumberOfArgumentsL(int)
	CommandNameLC__14TTestDebugInfo @ 7 NONAME ; TTestDebugInfo::CommandNameLC(void)
	ConstructL__14CMsvClientTest @ 8 NONAME ; CMsvClientTest::ConstructL(void)
	ConstructL__16CBaseTestHarness @ 9 NONAME ; CBaseTestHarness::ConstructL(void)
	ConstructL__16CMainTestHarness @ 10 NONAME ; CMainTestHarness::ConstructL(void)
	ConstructL__18CBaseCommandParser @ 11 NONAME ; CBaseCommandParser::ConstructL(void)
	ConstructL__18CBaseSectionParserRC7TDesC16 @ 12 NONAME ; CBaseSectionParser::ConstructL(TDesC16 const &)
	ConstructL__18CMainSectionParser @ 13 NONAME ; CMainSectionParser::ConstructL(void)
	ConstructL__26CMsvTestEntrySectionParserRC7TDesC16 @ 14 NONAME ; CMsvTestEntrySectionParser::ConstructL(TDesC16 const &)
	CurrentCommandPosition__C12CTestSection @ 15 NONAME ; CTestSection::CurrentCommandPosition(void) const
	CurrentOperation__14CMsvClientTest @ 16 NONAME ; CMsvClientTest::CurrentOperation(void)
	DoCancel__14CCopySelection @ 17 NONAME ; CCopySelection::DoCancel(void)
	DoCancel__14CMoveSelection @ 18 NONAME ; CMoveSelection::DoCancel(void)
	DoCancel__14CMsvClientTest @ 19 NONAME ; CMsvClientTest::DoCancel(void)
	DoCancel__16CBaseTestHarness @ 20 NONAME ; CBaseTestHarness::DoCancel(void)
	DoCancel__16CDeleteSelection @ 21 NONAME ; CDeleteSelection::DoCancel(void)
	DoCancel__9CLongWait @ 22 NONAME ; CLongWait::DoCancel(void)
	Error__18CBaseCommandParser @ 23 NONAME ; CBaseCommandParser::Error(void)
	GetCurrentCommand__C12CTestSectionR6TDes16 @ 24 NONAME ; CTestSection::GetCurrentCommand(TDes16 &) const
	GetLineL__11CTestScriptRt5TBuf81i128i @ 25 NONAME ; CTestScript::GetLineL(TBuf8<128> &, int)
	GetSectionL__11CTestScriptRC7TDesC16 @ 26 NONAME ; CTestScript::GetSectionL(TDesC16 const &)
	LineNumber__14TTestDebugInfo @ 27 NONAME ; TTestDebugInfo::LineNumber(void)
	LoadFileL__11CTestScriptRC7TDesC16 @ 28 NONAME ; CTestScript::LoadFileL(TDesC16 const &)
	LogCommentL__16CBaseTestHarnessRC7TDesC16 @ 29 NONAME ; CBaseTestHarness::LogCommentL(TDesC16 const &)
	LogCommentL__18CMainSectionParserRC7TDesC16 @ 30 NONAME ; CMainSectionParser::LogCommentL(TDesC16 const &)
	LogCommentL__26CMsvTestEntrySectionParserRC7TDesC16 @ 31 NONAME ; CMsvTestEntrySectionParser::LogCommentL(TDesC16 const &)
	MsvTestUtils__14CMsvClientTest @ 32 NONAME ; CMsvClientTest::MsvTestUtils(void)
	NewL__11CAddCommentRC16CDesC16ArrayFlatR13CMsvTestUtils @ 33 NONAME ; CAddComment::NewL(CDesC16ArrayFlat const &, CMsvTestUtils &)
	NewL__11CTestScriptR3RFs @ 34 NONAME ; CTestScript::NewL(RFs &)
	NewL__12CSelectEntryRC7TDesC16RClP18CMsvEntrySelectionR13CMsvTestUtils @ 35 NONAME ; CSelectEntry::NewL(TDesC16 const &, long const &, CMsvEntrySelection *, CMsvTestUtils &)
	NewL__12CSelectEntryRC7TDesC16RClPlR13CMsvTestUtils @ 36 NONAME ; CSelectEntry::NewL(TDesC16 const &, long const &, long *, CMsvTestUtils &)
	NewL__12CTestSectioniRC7TDesC16i @ 37 NONAME ; CTestSection::NewL(int, TDesC16 const &, int)
	NewL__14CCheckBodyTextiR7TDesC16R18CMsvEntrySelectionR13CMsvTestUtils @ 38 NONAME ; CCheckBodyText::NewL(int, TDesC16 &, CMsvEntrySelection &, CMsvTestUtils &)
	NewL__14CMsvClientTestP13CMsvTestUtilsR5RTest @ 39 NONAME ; CMsvClientTest::NewL(CMsvTestUtils *, RTest &)
	NewL__14CMsvClientTestR13CMsvTestUtilsR5RTest @ 40 NONAME ; CMsvClientTest::NewL(CMsvTestUtils &, RTest &)
	NewL__16CMainTestHarnessR5RTest @ 41 NONAME ; CMainTestHarness::NewL(RTest &)
	NewL__16CMsvSelectParserR14CMsvClientTest @ 42 NONAME ; CMsvSelectParser::NewL(CMsvClientTest &)
	NewL__18CMainSectionParserR16CMainTestHarnessR11CTestScript @ 43 NONAME ; CMainSectionParser::NewL(CMainTestHarness &, CTestScript &)
	NewL__19CMsvOperationParserR14CMsvClientTest @ 44 NONAME ; CMsvOperationParser::NewL(CMsvClientTest &)
	NewL__19CMsvUtilitiesParserR14CMsvClientTest @ 45 NONAME ; CMsvUtilitiesParser::NewL(CMsvClientTest &)
	NewL__26CMsvTestEntryCommandParserR13CMsvTestEntry @ 46 NONAME ; CMsvTestEntryCommandParser::NewL(CMsvTestEntry &)
	NewL__26CMsvTestEntrySectionParserRC7TDesC16R11CTestScriptR13CMsvTestEntry @ 47 NONAME ; CMsvTestEntrySectionParser::NewL(TDesC16 const &, CTestScript &, CMsvTestEntry &)
	NextCommand__12CTestSection @ 48 NONAME ; CTestSection::NextCommand(void)
	ParseL__18CBaseCommandParserRC7TDesC16G14TTestDebugInfo @ 49 NONAME ; CBaseCommandParser::ParseL(TDesC16 const &, TTestDebugInfo)
	ParseL__18CBaseSectionParser @ 50 NONAME ; CBaseSectionParser::ParseL(void)
	ProcessL__16CMsvSelectParser @ 51 NONAME ; CMsvSelectParser::ProcessL(void)
	ProcessL__19CMsvOperationParser @ 52 NONAME ; CMsvOperationParser::ProcessL(void)
	ProcessL__19CMsvUtilitiesParser @ 53 NONAME ; CMsvUtilitiesParser::ProcessL(void)
	ProcessL__26CMsvTestEntryCommandParser @ 54 NONAME ; CMsvTestEntryCommandParser::ProcessL(void)
	Reset__14CMsvClientTest @ 55 NONAME ; CMsvClientTest::Reset(void)
	RunError__16CActiveTestStatei @ 56 NONAME ; CActiveTestState::RunError(int)
	RunError__16CBaseTestHarnessi @ 57 NONAME ; CBaseTestHarness::RunError(int)
	RunL__14CCopySelection @ 58 NONAME ; CCopySelection::RunL(void)
	RunL__14CMoveSelection @ 59 NONAME ; CMoveSelection::RunL(void)
	RunL__16CBaseTestHarness @ 60 NONAME ; CBaseTestHarness::RunL(void)
	RunL__16CDeleteSelection @ 61 NONAME ; CDeleteSelection::RunL(void)
	RunL__9CLongWait @ 62 NONAME ; CLongWait::RunL(void)
	SectionNameLC__14TTestDebugInfo @ 63 NONAME ; TTestDebugInfo::SectionNameLC(void)
	SectionName__C12CTestSection @ 64 NONAME ; CTestSection::SectionName(void) const
	SectionPosition__C12CTestSection @ 65 NONAME ; CTestSection::SectionPosition(void) const
	SetCurrentOperation__14CMsvClientTestP13CMsvOperation @ 66 NONAME ; CMsvClientTest::SetCurrentOperation(CMsvOperation *)
	SetErrorL__18CBaseCommandParserRC7TDesC16 @ 67 NONAME ; CBaseCommandParser::SetErrorL(TDesC16 const &)
	SetHeapFailureTesting__16CBaseTestHarnessi @ 68 NONAME ; CBaseTestHarness::SetHeapFailureTesting(int)
	SetTestHarnessName__14TTestDebugInfoi @ 69 NONAME ; TTestDebugInfo::SetTestHarnessName(int)
	StartL__11CAddCommentR14TRequestStatus @ 70 NONAME ; CAddComment::StartL(TRequestStatus &)
	StartL__12CSelectEntryR14TRequestStatus @ 71 NONAME ; CSelectEntry::StartL(TRequestStatus &)
	StartL__13CCheckNewFlagR14TRequestStatus @ 72 NONAME ; CCheckNewFlag::StartL(TRequestStatus &)
	StartL__13CGoClientSideR14TRequestStatus @ 73 NONAME ; CGoClientSide::StartL(TRequestStatus &)
	StartL__13CGoServerSideR14TRequestStatus @ 74 NONAME ; CGoServerSide::StartL(TRequestStatus &)
	StartL__13CMsvTestEntryR14TRequestStatus @ 75 NONAME ; CMsvTestEntry::StartL(TRequestStatus &)
	StartL__14CCheckBodyTextR14TRequestStatus @ 76 NONAME ; CCheckBodyText::StartL(TRequestStatus &)
	StartL__14CCheckPriorityR14TRequestStatus @ 77 NONAME ; CCheckPriority::StartL(TRequestStatus &)
	StartL__14CCopySelectionR14TRequestStatus @ 78 NONAME ; CCopySelection::StartL(TRequestStatus &)
	StartL__14CMoveSelectionR14TRequestStatus @ 79 NONAME ; CMoveSelection::StartL(TRequestStatus &)
	StartL__16CBaseTestHarnessR14TRequestStatus @ 80 NONAME ; CBaseTestHarness::StartL(TRequestStatus &)
	StartL__16CCheckAttachmentR14TRequestStatus @ 81 NONAME ; CCheckAttachment::StartL(TRequestStatus &)
	StartL__16CDeleteSelectionR14TRequestStatus @ 82 NONAME ; CDeleteSelection::StartL(TRequestStatus &)
	StartL__16CMainTestHarnessR14TRequestStatus @ 83 NONAME ; CMainTestHarness::StartL(TRequestStatus &)
	StartL__16CSelectEntryByIdR14TRequestStatus @ 84 NONAME ; CSelectEntryById::StartL(TRequestStatus &)
	StartL__17CDumpMessageStoreR14TRequestStatus @ 85 NONAME ; CDumpMessageStore::StartL(TRequestStatus &)
	StartL__18CSelectAllMessagesR14TRequestStatus @ 86 NONAME ; CSelectAllMessages::StartL(TRequestStatus &)
	StartL__19CCheckMessageFolderR14TRequestStatus @ 87 NONAME ; CCheckMessageFolder::StartL(TRequestStatus &)
	StartL__19CCleanMessageFolderR14TRequestStatus @ 88 NONAME ; CCleanMessageFolder::StartL(TRequestStatus &)
	StartL__19CResetMessageServerR14TRequestStatus @ 89 NONAME ; CResetMessageServer::StartL(TRequestStatus &)
	StartL__20CCheckSelectionCountR14TRequestStatus @ 90 NONAME ; CCheckSelectionCount::StartL(TRequestStatus &)
	StartL__22CCheckRemoteFolderSizeR14TRequestStatus @ 91 NONAME ; CCheckRemoteFolderSize::StartL(TRequestStatus &)
	StartL__22CSelectLastInSelectionR14TRequestStatus @ 92 NONAME ; CSelectLastInSelection::StartL(TRequestStatus &)
	StartL__23CSelectFirstInSelectionR14TRequestStatus @ 93 NONAME ; CSelectFirstInSelection::StartL(TRequestStatus &)
	StartL__27CSelectPopulatedInSelectionR14TRequestStatus @ 94 NONAME ; CSelectPopulatedInSelection::StartL(TRequestStatus &)
	StartL__9CLongWaitR14TRequestStatus @ 95 NONAME ; CLongWait::StartL(TRequestStatus &)
	TestCompleteStringLC__14TTestDebugInfo @ 96 NONAME ; TTestDebugInfo::TestCompleteStringLC(void)
	TestComplete__13CMsvTestEntryi @ 97 NONAME ; CMsvTestEntry::TestComplete(int)
	TestConsole__16CBaseTestHarness @ 98 NONAME ; CBaseTestHarness::TestConsole(void)
	TestFailedStringLC__14TTestDebugInfoi @ 99 NONAME ; TTestDebugInfo::TestFailedStringLC(int)
	TestHarnessNameLC__14TTestDebugInfo @ 100 NONAME ; TTestDebugInfo::TestHarnessNameLC(void)
	TestStartStringLC__14TTestDebugInfo @ 101 NONAME ; TTestDebugInfo::TestStartStringLC(void)
	TestVisible__13CMsvTestEntryi @ 102 NONAME ; CMsvTestEntry::TestVisible(int)
	"_._11CAddComment" @ 103 NONAME ; CAddComment::~CAddComment(void)
	"_._11CTestScript" @ 104 NONAME ; CTestScript::~CTestScript(void)
	"_._12CSelectEntry" @ 105 NONAME ; CSelectEntry::~CSelectEntry(void)
	"_._12CTestSection" @ 106 NONAME ; CTestSection::~CTestSection(void)
	"_._14CCheckBodyText" @ 107 NONAME ; CCheckBodyText::~CCheckBodyText(void)
	"_._14CCopySelection" @ 108 NONAME ; CCopySelection::~CCopySelection(void)
	"_._14CMoveSelection" @ 109 NONAME ; CMoveSelection::~CMoveSelection(void)
	"_._14CMsvClientTest" @ 110 NONAME ; CMsvClientTest::~CMsvClientTest(void)
	"_._16CBaseTestHarness" @ 111 NONAME ; CBaseTestHarness::~CBaseTestHarness(void)
	"_._16CDeleteSelection" @ 112 NONAME ; CDeleteSelection::~CDeleteSelection(void)
	"_._18CBaseCommandParser" @ 113 NONAME ; CBaseCommandParser::~CBaseCommandParser(void)
	"_._18CBaseSectionParser" @ 114 NONAME ; CBaseSectionParser::~CBaseSectionParser(void)
	"_._26CMsvTestEntrySectionParser" @ 115 NONAME ; CMsvTestEntrySectionParser::~CMsvTestEntrySectionParser(void)
	"_._9CLongWait" @ 116 NONAME ; CLongWait::~CLongWait(void)
	__13CCheckNewFlagiiR18CMsvEntrySelectionR13CMsvTestUtils @ 117 NONAME ; CCheckNewFlag::CCheckNewFlag(int, int, CMsvEntrySelection &, CMsvTestUtils &)
	__13CGoClientSideR13CMsvTestUtils @ 118 NONAME ; CGoClientSide::CGoClientSide(CMsvTestUtils &)
	__13CGoServerSideR13CMsvTestUtils @ 119 NONAME ; CGoServerSide::CGoServerSide(CMsvTestUtils &)
	__13CMsvTestEntryR14CMsvClientTest @ 120 NONAME ; CMsvTestEntry::CMsvTestEntry(CMsvClientTest &)
	__14CCheckPriorityiiR18CMsvEntrySelectionR13CMsvTestUtils @ 121 NONAME ; CCheckPriority::CCheckPriority(int, int, CMsvEntrySelection &, CMsvTestUtils &)
	__14CCopySelectionR14CMsvClientTest @ 122 NONAME ; CCopySelection::CCopySelection(CMsvClientTest &)
	__14CMoveSelectionR14CMsvClientTest @ 123 NONAME ; CMoveSelection::CMoveSelection(CMsvClientTest &)
	__14CMsvClientTestP13CMsvTestUtilsR5RTest @ 124 NONAME ; CMsvClientTest::CMsvClientTest(CMsvTestUtils *, RTest &)
	__14CMsvClientTestR13CMsvTestUtilsR5RTest @ 125 NONAME ; CMsvClientTest::CMsvClientTest(CMsvTestUtils &, RTest &)
	__14TTestDebugInfo @ 126 NONAME ; TTestDebugInfo::TTestDebugInfo(void)
	__14TTestDebugInfoR11CTestScriptii @ 127 NONAME ; TTestDebugInfo::TTestDebugInfo(CTestScript &, int, int)
	__14TTestDebugInfoR11CTestScriptiii @ 128 NONAME ; TTestDebugInfo::TTestDebugInfo(CTestScript &, int, int, int)
	__16CActiveTestStatei @ 129 NONAME ; CActiveTestState::CActiveTestState(int)
	__16CBaseTestHarnessR5RTest @ 130 NONAME ; CBaseTestHarness::CBaseTestHarness(RTest &)
	__16CCheckAttachmentiiR18CMsvEntrySelectionR13CMsvTestUtils @ 131 NONAME ; CCheckAttachment::CCheckAttachment(int, int, CMsvEntrySelection &, CMsvTestUtils &)
	__16CDeleteSelectionR14CMsvClientTest @ 132 NONAME ; CDeleteSelection::CDeleteSelection(CMsvClientTest &)
	__16CMainTestHarnessR5RTest @ 133 NONAME ; CMainTestHarness::CMainTestHarness(RTest &)
	__16CSelectEntryByIdlRlR13CMsvTestUtils @ 134 NONAME ; CSelectEntryById::CSelectEntryById(long, long &, CMsvTestUtils &)
	__17CDumpMessageStoreR13CMsvTestUtils @ 135 NONAME ; CDumpMessageStore::CDumpMessageStore(CMsvTestUtils &)
	__18CBaseCommandParser @ 136 NONAME ; CBaseCommandParser::CBaseCommandParser(void)
	__18CBaseSectionParserR11CTestScript @ 137 NONAME ; CBaseSectionParser::CBaseSectionParser(CTestScript &)
	__18CMainSectionParserR16CMainTestHarnessR11CTestScript @ 138 NONAME ; CMainSectionParser::CMainSectionParser(CMainTestHarness &, CTestScript &)
	__18CSelectAllMessagesRlR18CMsvEntrySelectionR13CMsvTestUtils @ 139 NONAME ; CSelectAllMessages::CSelectAllMessages(long &, CMsvEntrySelection &, CMsvTestUtils &)
	__19CCheckMessageFolderRC7TDesC16R13CMsvTestUtils @ 140 NONAME ; CCheckMessageFolder::CCheckMessageFolder(TDesC16 const &, CMsvTestUtils &)
	__19CCleanMessageFolderR13CMsvTestUtils @ 141 NONAME ; CCleanMessageFolder::CCleanMessageFolder(CMsvTestUtils &)
	__19CResetMessageServerR14CMsvClientTest @ 142 NONAME ; CResetMessageServer::CResetMessageServer(CMsvClientTest &)
	__20CCheckSelectionCountiR18CMsvEntrySelectionR13CMsvTestUtils @ 143 NONAME ; CCheckSelectionCount::CCheckSelectionCount(int, CMsvEntrySelection &, CMsvTestUtils &)
	__22CCheckRemoteFolderSizeiR13CMsvTestUtils @ 144 NONAME ; CCheckRemoteFolderSize::CCheckRemoteFolderSize(int, CMsvTestUtils &)
	__22CSelectLastInSelectioniR18CMsvEntrySelectionR13CMsvTestUtils @ 145 NONAME ; CSelectLastInSelection::CSelectLastInSelection(int, CMsvEntrySelection &, CMsvTestUtils &)
	__23CSelectFirstInSelectioniR18CMsvEntrySelectionR13CMsvTestUtils @ 146 NONAME ; CSelectFirstInSelection::CSelectFirstInSelection(int, CMsvEntrySelection &, CMsvTestUtils &)
	__26CMsvTestEntrySectionParserR11CTestScriptR13CMsvTestEntry @ 147 NONAME ; CMsvTestEntrySectionParser::CMsvTestEntrySectionParser(CTestScript &, CMsvTestEntry &)
	__27CSelectPopulatedInSelectionR18CMsvEntrySelectionR13CMsvTestUtils @ 148 NONAME ; CSelectPopulatedInSelection::CSelectPopulatedInSelection(CMsvEntrySelection &, CMsvTestUtils &)
	__9CLongWait @ 149 NONAME ; CLongWait::CLongWait(void)
	AddCommandL__12CTestSectionRCt5TBuf81i128ii @ 150 NONAME ; CTestSection::AddCommandL(TBuf8<128> const &, int, int)

